package com.ruoyi.web.controller.rc;

import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.system.service.ISysDeptService;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.rc.domain.TQuestionnaireTemplate;
import com.ruoyi.rc.service.ITQuestionnaireTemplateService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.StringUtils;

/**
 * 问卷模板Controller
 * 
 * @author ruoyi
 * @date 2024-07-31
 */
@RestController
@RequestMapping("/rc/questionnairetemplate")
public class TQuestionnaireTemplateController extends BaseController
{
    @Autowired
    private ITQuestionnaireTemplateService tQuestionnaireTemplateService;

    @Autowired
    private ISysDeptService deptService;

    /**
     * 查询问卷模板列表
     */
    @PreAuthorize("@ss.hasPermi('rc:questionnairetemplate:list')")
    @GetMapping("/list")
    public TableDataInfo list(TQuestionnaireTemplate tQuestionnaireTemplate)
    {
        startPage();
        List<TQuestionnaireTemplate> list = tQuestionnaireTemplateService.selectTQuestionnaireTemplateList(tQuestionnaireTemplate);
        for (TQuestionnaireTemplate obj : list) {
            String deptId = obj.getDeptId();
            if (StringUtils.isNotEmpty(deptId)) {
                if (deptId.indexOf(",") != -1) {
                    StringBuffer sb = new StringBuffer();
                    String[] ids = deptId.split(",");
                    for (String id : ids) {
                        SysDept sysDept = deptService.selectDeptById(Long.parseLong(id));
                        sb.append(sysDept.getDeptName()).append(" / ");
                    }
                    obj.setDeptName(sb.toString().substring(0, sb.length() - 3));
                } else {
                    obj.setDeptName(deptService.selectDeptById(Long.parseLong(deptId)).getDeptName());
                }
            }
        }
        return getDataTable(list);
    }

    /**
     * 导出问卷模板列表
     */
    @PreAuthorize("@ss.hasPermi('rc:questionnairetemplate:export')")
    @Log(title = "问卷模板", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TQuestionnaireTemplate tQuestionnaireTemplate)
    {
        List<TQuestionnaireTemplate> list = tQuestionnaireTemplateService.selectTQuestionnaireTemplateList(tQuestionnaireTemplate);
        ExcelUtil<TQuestionnaireTemplate> util = new ExcelUtil<TQuestionnaireTemplate>(TQuestionnaireTemplate.class);
        util.exportExcel(response, list, "问卷模板数据");
    }

    /**
     * 获取问卷模板详细信息
     */
    @PreAuthorize("@ss.hasPermi('rc:questionnairetemplate:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tQuestionnaireTemplateService.selectTQuestionnaireTemplateById(id));
    }

    /**
     * 新增问卷模板
     */
    @PreAuthorize("@ss.hasPermi('rc:questionnairetemplate:add')")
    @Log(title = "问卷模板", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TQuestionnaireTemplate tQuestionnaireTemplate)
    {
        if (StringUtils.isNull(tQuestionnaireTemplate.getDeptId()) || "".equals(tQuestionnaireTemplate.getDeptId())) {
            tQuestionnaireTemplate.setDeptId(getLoginUser().getDeptId().toString());
        }
        return toAjax(tQuestionnaireTemplateService.insertTQuestionnaireTemplate(tQuestionnaireTemplate));
    }

    /**
     * 修改问卷模板
     */
    @PreAuthorize("@ss.hasPermi('rc:questionnairetemplate:edit')")
    @Log(title = "问卷模板", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TQuestionnaireTemplate tQuestionnaireTemplate)
    {
        return toAjax(tQuestionnaireTemplateService.updateTQuestionnaireTemplate(tQuestionnaireTemplate));
    }

    /**
     * 删除问卷模板
     */
    @PreAuthorize("@ss.hasPermi('rc:questionnairetemplate:remove')")
    @Log(title = "问卷模板", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tQuestionnaireTemplateService.deleteTQuestionnaireTemplateByIds(ids));
    }
}
