-- ----------------------------
-- 审计记录表
-- ----------------------------
create table t_audit (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  `year`            year          comment '年份',
  pre_audit_time    datetime      comment '预审时间',
  audit_time        datetime      comment '审计时间',
  audit_result      varchar(500)  comment '审计结果',
  remarks           varchar(500)  comment '备注',
  dept_id           varchar(255)  comment '装置id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '审计记录表';

-- ----------------------------
-- 装置信息表
-- ----------------------------
create table t_dept_info (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  `year`            year          comment '年份',
  dept_info         varchar(500)  comment '装置信息',
  dept_id           varchar(255)  comment '装置id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '装置信息表';

-- ----------------------------
-- 章节表
-- ----------------------------
create table t_chapter (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  audit_id          bigint(20)    comment '审计记录id',
  code              varchar(8)    comment '序号',
  name              varchar(500)  comment '名称',
  dept_id           varchar(255)  comment '装置id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '章节表';

-- ----------------------------
-- 章节模板表
-- ----------------------------
create table t_chapter_template (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  code              varchar(8)    comment '序号',
  name              varchar(500)  comment '名称',
  dept_id           varchar(255)  comment '装置id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '章节模板表';

-- ----------------------------
-- 问卷表
-- ----------------------------
create table t_questionnaire (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  audit_id          bigint(20)    comment '审计记录id',
  chapter_id        bigint(20)    comment '章节id',
  year              year          comment '年份',
  type              char(1)       comment '问卷类型',
  directory         varchar(500)  comment '目录',
  code              bigint(20)    comment '序号',
  name              varchar(500)  comment '名称',
  yes_no_na         char(1)       comment 'YES/NO/NA',
  minimum_standard  varchar(500)  comment 'MinimumStandard',
  good_practices    varchar(500)  comment 'Good Practices',
  standard         char(1)        comment '标准',
  completion_status char(1)       comment '完成情况',
  person_in_charge  bigint(20)    comment '负责人',
  reviewer          bigint(20)    comment '审核人',
  remarks           varchar(500)  comment '备注',
  dept_id           varchar(255)  comment '装置id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '问卷表';

-- ----------------------------
-- 问卷模板表
-- ----------------------------
create table t_questionnaire_template (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  chapter_id        bigint(20)    comment '章节id',
  type              char(1)       comment '问卷类型',
  directory         varchar(500)  comment '目录',
  code              bigint(20)    comment '序号',
  name              varchar(500)  comment '名称',
  dept_id           varchar(255)  comment '装置id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '问卷模板表';

-- ----------------------------
-- 进度表
-- ----------------------------
create table t_progress (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  questionnaire_id   bigint(20)   comment '问卷id',
  chap_name         varchar(500)  comment '章节',
  sub_chap_name     varchar(500)  comment '细分章节',
  sec_sub_chap_name varchar(500)  comment '二级细分章节',
  content           varchar(500)  comment '内容',
  person_in_charge  bigint(20)    comment '负责人',
  supporter         bigint(20)    comment '支持人',
  start_date        datetime      comment '开始日期',
  target_date       datetime      comment '目标日期',
  finish_date       datetime      comment '实际完成日期',
  preparation       char(1)       comment '准备情况',
  description          char(1)    comment '进度描述',
  apply_status      char(1)       comment '审批状态',
  remarks           varchar(500)  comment '备注',
  dept_id           varchar(255)  comment '装置id',
  audit_id          bigint(20)    comment '审计记录id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '进度表';

-- ----------------------------
-- 会议表
-- ----------------------------
create table t_meeting (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  year              year          comment '年份',
  questionnaire_id   bigint(20)   comment '涉及code',
  person_in_charge  bigint(20)    comment '负责人',
  remarks           varchar(500)  comment '备注',
  dept_id           varchar(255)  comment '装置id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '会议表';

-- ----------------------------
-- 开项表
-- ----------------------------
create table t_open_item (
  id                bigint(20)    comment 'id'  not null  auto_increment,
  type              char(1)       comment '问题类型',
  questionnaire_id   bigint(20)   comment '涉及整改code',
  description       varchar(500)  comment '存在问题描述',
  level             char(1)       comment '开项级别',
  open_time         datetime      comment '开项时间',
  close_time        datetime      comment '闭项时间',
  status            char(1)       comment '问题处理状态',
  person_in_charge  bigint(20)    comment '负责人',
  reviewer          bigint(20)    comment '审核人',
  result            char(1)       comment '责任人确认',
  deadline          datetime      comment '截至时间',
  remarks           varchar(500)  comment '备注',
  dept_id           varchar(255)  comment '装置id',
  primary key (id)
) engine=innodb auto_increment=100 comment = '开项表';

-- ----------------------------
-- 通用附件表
-- ----------------------------
create table t_commonfile
(
  id bigint(20) comment 'id' not null auto_increment,
  p_id bigint(20) comment '业务id',
  file_name varchar(255) comment '文件名',
  file_url varchar(500) comment '路径',
  del_flag bigint(20) default 0 comment '删除标识',
  creater_code varchar(255) comment '创建人',
  createdate datetime comment '创建时间',
  updater_code varchar(255) comment '更新人',
  updatedate datetime comment '更新时间',
  remarks varchar(255) comment '备注',
  p_type varchar(64) comment '业务类型',
  file_size varchar(128) comment '文件大小',
  p_value varchar(1000) comment '业务字段',
  p_date datetime comment '业务时间',
	primary key (id)
) engine=innodb auto_increment=100 comment = '通用附件表';

-- ----------------------------
-- Activiti表
-- ----------------------------
create table ACT_GE_BYTEARRAY
(
  ID_ VARCHAR(64) not null,
  REV_ int,
  NAME_ VARCHAR(255),
  DEPLOYMENT_ID_ VARCHAR(64),
  BYTES_ BLOB,
  GENERATED_ int(1),
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_GE_PROPERTY
(
  NAME_ VARCHAR(64) not null,
  VALUE_ VARCHAR(300),
  REV_ int,
  primary key (NAME_)
)engine=innodb auto_increment=100;
create table ACT_HI_ACTINST
(
  ID_ VARCHAR(64) not null,
  PROC_DEF_ID_ VARCHAR(64) not null,
  PROC_INST_ID_ VARCHAR(64) not null,
  EXECUTION_ID_ VARCHAR(64) not null,
  ACT_ID_ VARCHAR(255) not null,
  TASK_ID_ VARCHAR(64),
  CALL_PROC_INST_ID_ VARCHAR(64),
  ACT_NAME_ VARCHAR(255),
  ACT_TYPE_ VARCHAR(255) not null,
  ASSIGNEE_ VARCHAR(255),
  START_TIME_ TIMESTAMP(6) not null,
  END_TIME_ TIMESTAMP(6),
  DURATION_ int(19),
  DELETE_REASON_ VARCHAR(2000),
  TENANT_ID_ VARCHAR(255) default '',
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_HI_ATTACHMENT
(
  ID_ VARCHAR(64) not null,
  REV_ int,
  USER_ID_ VARCHAR(255),
  NAME_ VARCHAR(255),
  DESCRIPTION_ VARCHAR(2000),
  TYPE_ VARCHAR(255),
  TASK_ID_ VARCHAR(64),
  PROC_INST_ID_ VARCHAR(64),
  URL_ VARCHAR(2000),
  CONTENT_ID_ VARCHAR(64),
  TIME_ TIMESTAMP(6),
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_HI_COMMENT
(
  ID_ VARCHAR(64) not null,
  TYPE_ VARCHAR(255),
  TIME_ TIMESTAMP(6) not null,
  USER_ID_ VARCHAR(255),
  TASK_ID_ VARCHAR(64),
  PROC_INST_ID_ VARCHAR(64),
  ACTION_ VARCHAR(255),
  MESSAGE_ VARCHAR(2000),
  FULL_MSG_ BLOB,
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_HI_DETAIL
(
  ID_ VARCHAR(64) not null,
  TYPE_ VARCHAR(255) not null,
  PROC_INST_ID_ VARCHAR(64),
  EXECUTION_ID_ VARCHAR(64),
  TASK_ID_ VARCHAR(64),
  ACT_INST_ID_ VARCHAR(64),
  NAME_ VARCHAR(255) not null,
  VAR_TYPE_ VARCHAR(64),
  REV_ int,
  TIME_ TIMESTAMP(6) not null,
  BYTEARRAY_ID_ VARCHAR(64),
  DOUBLE_ int,
  LONG_ int(19),
  TEXT_ VARCHAR(2000),
  TEXT2_ VARCHAR(2000),
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_HI_IDENTITYLINK
(
  ID_ VARCHAR(64) not null,
  GROUP_ID_ VARCHAR(255),
  TYPE_ VARCHAR(255),
  USER_ID_ VARCHAR(255),
  TASK_ID_ VARCHAR(64),
  PROC_INST_ID_ VARCHAR(64),
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_HI_PROCINST
(
  ID_ VARCHAR(64) not null,
  PROC_INST_ID_ VARCHAR(64) not null,
  BUSINESS_KEY_ VARCHAR(255),
  PROC_DEF_ID_ VARCHAR(64) not null,
  START_TIME_ TIMESTAMP(6) not null,
  END_TIME_ TIMESTAMP(6),
  DURATION_ int(19),
  START_USER_ID_ VARCHAR(255),
  START_ACT_ID_ VARCHAR(255),
  END_ACT_ID_ VARCHAR(255),
  SUPER_PROCESS_INSTANCE_ID_ VARCHAR(64),
  DELETE_REASON_ VARCHAR(2000),
  TENANT_ID_ VARCHAR(255) default '',
  NAME_ VARCHAR(255),
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_HI_TASKINST
(
  ID_ VARCHAR(64) not null,
  PROC_DEF_ID_ VARCHAR(64),
  TASK_DEF_KEY_ VARCHAR(255),
  PROC_INST_ID_ VARCHAR(64),
  EXECUTION_ID_ VARCHAR(64),
  PARENT_TASK_ID_ VARCHAR(64),
  NAME_ VARCHAR(255),
  DESCRIPTION_ VARCHAR(2000),
  OWNER_ VARCHAR(255),
  ASSIGNEE_ VARCHAR(255),
  START_TIME_ TIMESTAMP(6) not null,
  CLAIM_TIME_ TIMESTAMP(6),
  END_TIME_ TIMESTAMP(6),
  DURATION_ int(19),
  DELETE_REASON_ VARCHAR(2000),
  PRIORITY_ int,
  DUE_DATE_ TIMESTAMP(6),
  FORM_KEY_ VARCHAR(255),
  CATEGORY_ VARCHAR(255),
  TENANT_ID_ VARCHAR(255) default '',
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_HI_VARINST
(
  ID_ VARCHAR(64) not null,
  PROC_INST_ID_ VARCHAR(64),
  EXECUTION_ID_ VARCHAR(64),
  TASK_ID_ VARCHAR(64),
  NAME_ VARCHAR(255) not null,
  VAR_TYPE_ VARCHAR(100),
  REV_ int,
  BYTEARRAY_ID_ VARCHAR(64),
  DOUBLE_ int,
  LONG_ int(19),
  TEXT_ VARCHAR(2000),
  TEXT2_ VARCHAR(2000),
  CREATE_TIME_ TIMESTAMP(6),
  LAST_UPDATED_TIME_ TIMESTAMP(6),
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_ID_INFO
(
  ID_ VARCHAR(64) not null,
  REV_ int,
  USER_ID_ VARCHAR(64),
  TYPE_ VARCHAR(64),
  KEY_ VARCHAR(255),
  VALUE_ VARCHAR(255),
  PASSWORD_ BLOB,
  PARENT_ID_ VARCHAR(255),
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_PROCDEF_INFO
(
  ID_ VARCHAR(64) not null,
  PROC_DEF_ID_ VARCHAR(64) not null,
  REV_ int,
  INFO_JSON_ID_ VARCHAR(64),
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_RE_DEPLOYMENT
(
  ID_ VARCHAR(64) not null,
  NAME_ VARCHAR(255),
  CATEGORY_ VARCHAR(255),
  KEY_ VARCHAR(255),
  TENANT_ID_ VARCHAR(255) default '',
  DEPLOY_TIME_ TIMESTAMP(6),
  ENGINE_VERSION_ VARCHAR(255),
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_RE_MODEL
(
  ID_ VARCHAR(64) not null,
  REV_ int,
  NAME_ VARCHAR(255),
  KEY_ VARCHAR(255),
  CATEGORY_ VARCHAR(255),
  CREATE_TIME_ TIMESTAMP(6),
  LAST_UPDATE_TIME_ TIMESTAMP(6),
  VERSION_ int,
  META_INFO_ VARCHAR(2000),
  DEPLOYMENT_ID_ VARCHAR(64),
  EDITOR_SOURCE_VALUE_ID_ VARCHAR(64),
  EDITOR_SOURCE_EXTRA_VALUE_ID_ VARCHAR(64),
  TENANT_ID_ VARCHAR(255) default '',
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_RE_PROCDEF
(
  ID_ VARCHAR(64) not null,
  REV_ int,
  CATEGORY_ VARCHAR(255),
  NAME_ VARCHAR(255),
  KEY_ VARCHAR(255) not null,
  VERSION_ int not null,
  DEPLOYMENT_ID_ VARCHAR(64),
  RESOURCE_NAME_ VARCHAR(2000),
  DGRM_RESOURCE_NAME_ VARCHAR(4000),
  DESCRIPTION_ VARCHAR(2000),
  HAS_START_FORM_KEY_ int(1),
  HAS_GRAPHICAL_NOTATION_ int(1),
  SUSPENSION_STATE_ int,
  TENANT_ID_ VARCHAR(255) default '',
  ENGINE_VERSION_ VARCHAR(255),
  constraint ACT_UNIQ_PROCDEF
  unique (KEY_, VERSION_, TENANT_ID_),
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_RU_EVENT_SUBSCR
(
  ID_ VARCHAR(64) not null,
  REV_ int,
  EVENT_TYPE_ VARCHAR(255) not null,
  EVENT_NAME_ VARCHAR(255),
  EXECUTION_ID_ VARCHAR(64),
  PROC_INST_ID_ VARCHAR(64),
  ACTIVITY_ID_ VARCHAR(64),
  CONFIGURATION_ VARCHAR(255),
  CREATED_ TIMESTAMP(6) not null,
  PROC_DEF_ID_ VARCHAR(64),
  TENANT_ID_ VARCHAR(255) default '',
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_RU_EXECUTION
(
  ID_ VARCHAR(64) not null,
  REV_ int,
  PROC_INST_ID_ VARCHAR(64),
  BUSINESS_KEY_ VARCHAR(255),
  PARENT_ID_ VARCHAR(64),
  PROC_DEF_ID_ VARCHAR(64),
  SUPER_EXEC_ VARCHAR(64),
  ROOT_PROC_INST_ID_ VARCHAR(64),
  ACT_ID_ VARCHAR(255),
  IS_ACTIVE_ int(1),
  IS_CONCURRENT_ int(1),
  IS_SCOPE_ int(1),
  IS_EVENT_SCOPE_ int(1),
  IS_MI_ROOT_ int(1),
  SUSPENSION_STATE_ int,
  CACHED_ENT_STATE_ int,
  TENANT_ID_ VARCHAR(255) default '',
  NAME_ VARCHAR(255),
  START_TIME_ TIMESTAMP(6),
  START_USER_ID_ VARCHAR(255),
  LOCK_TIME_ TIMESTAMP(6),
  IS_COUNT_ENABLED_ int(1),
  EVT_SUBSCR_COUNT_ int,
  TASK_COUNT_ int,
  JOB_COUNT_ int,
  TIMER_JOB_COUNT_ int,
  SUSP_JOB_COUNT_ int,
  DEADLETTER_JOB_COUNT_ int,
  VAR_COUNT_ int,
  ID_LINK_COUNT_ int,
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_RU_DEADLETTER_JOB
(
  ID_ VARCHAR(64) not null,
  REV_ int,
  TYPE_ VARCHAR(255) not null,
  EXCLUSIVE_ int(1),
  EXECUTION_ID_ VARCHAR(64),
  PROCESS_INSTANCE_ID_ VARCHAR(64),
  PROC_DEF_ID_ VARCHAR(64),
  EXCEPTION_STACK_ID_ VARCHAR(64),
  EXCEPTION_MSG_ VARCHAR(2000),
  DUEDATE_ TIMESTAMP(6),
  REPEAT_ VARCHAR(255),
  HANDLER_TYPE_ VARCHAR(255),
  HANDLER_CFG_ VARCHAR(2000),
  TENANT_ID_ VARCHAR(255) default '',
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_RU_IDENTITYLINK
(
  ID_ VARCHAR(64) not null,
  REV_ int,
  GROUP_ID_ VARCHAR(255),
  TYPE_ VARCHAR(255),
  USER_ID_ VARCHAR(255),
  TASK_ID_ VARCHAR(64),
  PROC_INST_ID_ VARCHAR(64),
  PROC_DEF_ID_ VARCHAR(64),
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_RU_JOB
(
  ID_ VARCHAR(64) not null,
  REV_ int,
  TYPE_ VARCHAR(255) not null,
  LOCK_EXP_TIME_ TIMESTAMP(6),
  LOCK_OWNER_ VARCHAR(255),
  EXCLUSIVE_ int(1),
  EXECUTION_ID_ VARCHAR(64),
  PROCESS_INSTANCE_ID_ VARCHAR(64),
  PROC_DEF_ID_ VARCHAR(64),
  RETRIES_ int,
  EXCEPTION_STACK_ID_ VARCHAR(64),
  EXCEPTION_MSG_ VARCHAR(2000),
  DUEDATE_ TIMESTAMP(6),
  REPEAT_ VARCHAR(255),
  HANDLER_TYPE_ VARCHAR(255),
  HANDLER_CFG_ VARCHAR(2000),
  TENANT_ID_ VARCHAR(255) default '',
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_RU_SUSPENDED_JOB
(
  ID_ VARCHAR(64) not null,
  REV_ int,
  TYPE_ VARCHAR(255) not null,
  EXCLUSIVE_ int(1),
  PROCESS_INSTANCE_ID_ VARCHAR(64),
  RETRIES_ int,
  EXCEPTION_STACK_ID_ VARCHAR(64),
  EXCEPTION_MSG_ VARCHAR(2000),
  DUEDATE_ TIMESTAMP(6),
  REPEAT_ VARCHAR(255),
  HANDLER_TYPE_ VARCHAR(255),
  HANDLER_CFG_ VARCHAR(2000),
  TENANT_ID_ VARCHAR(255) default '',
  EXECUTION_ID_ VARCHAR(64),
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_RU_TASK
(
  ID_ VARCHAR(64) not null,
  REV_ int,
  EXECUTION_ID_ VARCHAR(64),
  PROC_INST_ID_ VARCHAR(64),
  PROC_DEF_ID_ VARCHAR(64),
  NAME_ VARCHAR(255),
  PARENT_TASK_ID_ VARCHAR(64),
  DESCRIPTION_ VARCHAR(2000),
  TASK_DEF_KEY_ VARCHAR(255),
  OWNER_ VARCHAR(255),
  ASSIGNEE_ VARCHAR(255),
  DELEGATION_ VARCHAR(64),
  PRIORITY_ int,
  CREATE_TIME_ TIMESTAMP(6),
  DUE_DATE_ TIMESTAMP(6),
  CATEGORY_ VARCHAR(255),
  SUSPENSION_STATE_ int,
  TENANT_ID_ VARCHAR(255) default '',
  FORM_KEY_ VARCHAR(255),
  CLAIM_TIME_ TIMESTAMP(6),
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_RU_TIMER_JOB
(
  ID_ VARCHAR(64) not null,
  REV_ int,
  TYPE_ VARCHAR(255) not null,
  LOCK_EXP_TIME_ TIMESTAMP(6),
  LOCK_OWNER_ VARCHAR(255),
  EXCLUSIVE_ int(1),
  EXECUTION_ID_ VARCHAR(64),
  PROCESS_INSTANCE_ID_ VARCHAR(64),
  PROC_DEF_ID_ VARCHAR(64),
  RETRIES_ int,
  EXCEPTION_STACK_ID_ VARCHAR(64),
  EXCEPTION_MSG_ VARCHAR(2000),
  DUEDATE_ TIMESTAMP(6),
  REPEAT_ VARCHAR(255),
  HANDLER_TYPE_ VARCHAR(255),
  HANDLER_CFG_ VARCHAR(2000),
  TENANT_ID_ VARCHAR(255) default '',
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_RU_VARIABLE
(
  ID_ VARCHAR(64) not null,
  REV_ int,
  TYPE_ VARCHAR(255) not null,
  NAME_ VARCHAR(255) not null,
  EXECUTION_ID_ VARCHAR(64),
  PROC_INST_ID_ VARCHAR(64),
  TASK_ID_ VARCHAR(64),
  BYTEARRAY_ID_ VARCHAR(64),
  DOUBLE_ int,
  LONG_ int(19),
  TEXT_ VARCHAR(2000),
  TEXT2_ VARCHAR(2000),
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_EVT_LOG
(
  LOG_NR_ int(19) not null,
  TYPE_ VARCHAR(64),
  PROC_DEF_ID_ VARCHAR(64),
  PROC_INST_ID_ VARCHAR(64),
  EXECUTION_ID_ VARCHAR(64),
  TASK_ID_ VARCHAR(64),
  TIME_STAMP_ TIMESTAMP(6) not null,
  USER_ID_ VARCHAR(255),
  DATA_ BLOB,
  LOCK_OWNER_ VARCHAR(255),
  LOCK_TIME_ TIMESTAMP(6),
  IS_PROCESSED_ int(3) default 0,
  primary key (LOG_NR_)
)engine=innodb auto_increment=100;
create table ACT_ID_GROUP
(
  ID_ varchar(64) not null
    primary key,
  REV_ int,
  NAME_ varchar(255),
  TYPE_ varchar(255),
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_ID_USER
(
  ID_ varchar(64) not null,
  REV_ int,
  FIRST_ varchar(255),
  LAST_ varchar(255),
  EMAIL_ varchar(255),
  PWD_ varchar(255),
  PICTURE_ID_ varchar(64),
  primary key (ID_)
)engine=innodb auto_increment=100;
create table ACT_ID_MEMBERSHIP
(
  USER_ID_ varchar(64) not null,
  GROUP_ID_ varchar(64) not null,
  primary key (USER_ID_)
)engine=innodb auto_increment=100;

ALTER TABLE t_progress ADD process_id varchar(255) NULL COMMENT '流程id';
ALTER TABLE t_progress ADD ap_no varchar(255) NULL COMMENT '申请编号';
ALTER TABLE t_progress ADD task_id varchar(255) NULL COMMENT '任务编号';
ALTER TABLE t_progress ADD task_name varchar(255) NULL COMMENT '任务名称';

ALTER TABLE t_open_item ADD process_id varchar(255) NULL COMMENT '流程id';
ALTER TABLE t_open_item ADD ap_no varchar(255) NULL COMMENT '申请编号';

